#!/bin/bash
# This script made by syrupnx and licensed under MIT (see the included LICENSE.txt)
# For usage, see the included instructions.txt
#	Code based off of okatotf/swatch-clock on Github, a Javascript GNOME Shell extension

# This is version B of this script. It does not count milliseconds.
# It is meant for macOS, which does not have support for milliseconds in the date command at all.

# This script grabs the current Swatch Internet Time (aka .beat Time)
# This time system divides the day into 1000 parts called beats, and does not use timezones
# @0 represents midnight, and is based on midnight in UTC+1 (aka CET)
# The decimal places represent centibeats, and function like seconds in our standard time system

# This block defines our function
function getSwatchTime {
# These grab the different values of the date
# We apply 10# to each variable to denote that the value is in base 10 (decimal)
# Otherwise, values beginning with 0 would be considered in base 8 (octal)
# As such, a number such as 08 would trigger an error (Octal goes from 00-07)
	local -i CETHR=$[10#$(echo $[($(date -u +%H)+1)%24])] # Grab the current hour (in 24hrs) in UTC, add 1 to it, and modulo it by 24
# Doing modulo on the hour ensures that we don't get a value such as 25 (there aren't 25 hours in a day, after all)
	local -i CETM=10#$(date +%M) # Grabbing our other values in UTC is redundant (they're the same!)
	local -i CETS=10#$(date +%S)
# This takes all our values and puts it into one number
	local -i TIMEMS=$[(($CETHR*60+$CETM)*60+$CETS]
	local -i MSBEAT=86400 # This is the amount of milliseconds in a beat
# The scale denotes how many numbers after the decimal we want in our result
# Usually, we only count 2 centibeats
# Set the scale to 0 if you just want to see the beats
# Because we don't have milliseconds, some centibeats will be skipped as it is not as precise as version A
	SWATCHTIME=$(echo "scale=2; $TIMEMS/$MSBEAT"|bc -l)
}
# This calls our function and returns the result from it
getSwatchTime
# This echos the result
# The #- will get rid of the negative sign if present
echo @${SWATCHTIME#-}
